const int buttonRed = 8;    
const int buttonGreen = 7;
const int buttonYellow = 6; 
const int buttonLeft = 9; 
const int buttonRight = 10; 
const int ledRed =  2;     
const int ledGreen =  3;
const int ledBlue =  4;  
const int pinSound =  5; 
const int controlLeft =  9;
const int controlRight =  10;
const int lampLeft =  15;
const int lampRight =  16;
const int timeLimit =  10;  // sec
const int32_t timeDivider =  90000;  // repeats per sec
//------------------------------------
int buttonState = 0;  
int leftScore = 0;      
int rightScore = 0;   
int totalMode = 0;  
int timeOutCounter = -1;   
int32_t timeDivCounter = 0;    

void nonono() {
   digitalWrite(ledRed,  LOW);
   tone(pinSound, 200, 300);
   delay(400);
   digitalWrite(ledRed, HIGH);
   noTone(pinSound);
}

void bingo() {
   digitalWrite(ledGreen,  LOW);
   tone(pinSound, 400, 300);
   delay(400);
   tone(pinSound, 600, 600);
   delay(600);
   digitalWrite(ledGreen, HIGH);
   noTone(pinSound);
}

void setmode(int tMode) {
   switch(tMode) {
     case 0:  // init state
         digitalWrite(lampLeft, LOW);  
         digitalWrite(lampRight, LOW);
         digitalWrite(ledRed, LOW);
         digitalWrite(ledGreen, LOW);
         digitalWrite(ledBlue, LOW);
         break;

     case 1:  // question timeLimit timeout
         digitalWrite(lampLeft, LOW);  
         digitalWrite(lampRight, LOW);
         digitalWrite(ledRed, HIGH);
         digitalWrite(ledGreen, HIGH);
         digitalWrite(ledBlue, HIGH);          
         break;

     case 2:  // Left command answer
         digitalWrite(lampLeft, HIGH);  
         digitalWrite(lampRight, LOW);
         digitalWrite(ledRed, HIGH);
         digitalWrite(ledGreen, HIGH);
         digitalWrite(ledBlue, LOW);
         break;

     case 3:  // Right command answer
         digitalWrite(lampLeft, LOW);  
         digitalWrite(lampRight, HIGH);
         digitalWrite(ledRed, LOW);
         digitalWrite(ledGreen, HIGH);
         digitalWrite(ledBlue, HIGH);
         break;

     case 4:  // Left command answer timeout
     case 5:  // Right command answer timeout
         digitalWrite(lampLeft, LOW);  
         digitalWrite(lampRight, LOW);
         digitalWrite(ledRed, HIGH);
         digitalWrite(ledGreen, HIGH);
         digitalWrite(ledBlue, HIGH);       
         break;

     case 6:  // Left command answer after right
         digitalWrite(lampLeft, HIGH);  
         digitalWrite(lampRight, LOW);
         digitalWrite(ledRed, HIGH);
         digitalWrite(ledGreen, HIGH);
         digitalWrite(ledBlue, LOW);
         break;

     case 7:  // Right command answer after left
         digitalWrite(lampLeft, LOW);  
         digitalWrite(lampRight, HIGH);
         digitalWrite(ledRed, LOW);
         digitalWrite(ledGreen, HIGH);
         digitalWrite(ledBlue, HIGH);
         break;
   }
}

void setup() {
   pinMode(buttonRed, INPUT_PULLUP);
   pinMode(buttonGreen, INPUT_PULLUP);  
   pinMode(buttonYellow, INPUT_PULLUP);
   pinMode(buttonLeft, INPUT_PULLUP);
   pinMode(buttonRight, INPUT_PULLUP);
   pinMode(controlLeft, INPUT_PULLUP);
   pinMode(controlRight, INPUT_PULLUP);
   pinMode(ledRed, OUTPUT);
   pinMode(ledGreen, OUTPUT);
   pinMode(ledBlue, OUTPUT);
   pinMode(lampLeft, OUTPUT);
   pinMode(lampRight, OUTPUT);
   pinMode(pinSound, OUTPUT);
   setmode(totalMode);  
}

void loop() {
   if (digitalRead(buttonYellow) == LOW) { 
      timeOutCounter = -1;
      totalMode = 0;
      setmode(totalMode);  
   } 

   if (digitalRead(buttonLeft) == LOW) {  
      switch(totalMode) {
         case 1:  // question timeLimit timeout
            if (timeOutCounter > 0) { // time is not outed, next question
               totalMode = 2;
               tone(pinSound, 300, 250);
               setmode(totalMode); 
               timeOutCounter = -1;
               delay(260);
               noTone(pinSound);
            }
            break;

         case 4:  // Left command answer timeout
            if (timeOutCounter > 0) { // time is not outed, next question
               totalMode = 6;
               tone(pinSound, 300, 250);
               timeOutCounter = -1;
               setmode(totalMode); 
               delay(260);
               noTone(pinSound);
            }
            break;
      }
   }

   if (digitalRead(buttonRight) == LOW) {  
      switch(totalMode) {
         case 1:  // question timeLimit timeout
            if (timeOutCounter > 0) { // time is not outed, next question
               totalMode = 3;
               tone(pinSound, 300, 250);
               setmode(totalMode); 
               timeOutCounter = -1;
               delay(260);
               noTone(pinSound);
            }
            break;

         case 5:  // Right command answer timeout
            if (timeOutCounter > 0) { // time is not outed, next question
               totalMode = 7;
               tone(pinSound, 300, 250);
               setmode(totalMode); 
               timeOutCounter = -1;
               delay(260);
               noTone(pinSound);
            }
            break;
      }
   }

   if (digitalRead(buttonRed) == LOW) { 
      switch(totalMode) {
         case 0:  // init state
            totalMode = 1;
            timeOutCounter = timeLimit;
            break;

         case 1:  // question timeLimit timeout
            if (timeOutCounter == 0) { // time is outed, next question
               timeOutCounter = timeLimit; 
               nonono();
            }
            break;

         case 2:  // Left command answer
            totalMode = 5;
            timeOutCounter = timeLimit; 
            nonono();
            break;

         case 3:  // Right command answer
            totalMode = 4;
            timeOutCounter = timeLimit; 
            nonono();
            break;

         case 4:  // Left command answer timeout
         case 5:  // Right command answer timeout
            if (timeOutCounter == 0) { // time is outed, next question
               timeOutCounter = timeLimit; 
               totalMode = 1;
            }
            break;

         case 6:  // Left command answer after right
         case 7:  // Right command answer after left
            totalMode = 0;
            delay(250);
            nonono();
            break;
      }
      setmode(totalMode);  
   }

   if (digitalRead(buttonGreen) == LOW) {  
      switch(totalMode) {
         case 0:  // init state
            totalMode = 1;
            timeOutCounter = timeLimit;
            break;

         case 1:  // question timeLimit timeout
            if (timeOutCounter == 0) { // time is outed, next question
               timeOutCounter = timeLimit; 
            }
            break;

         case 2:  // Left command answer
            totalMode = 0;
            bingo();
            leftScore++;  
            break;

         case 3:  // Right command answer
            totalMode = 0;
            bingo();
            rightScore++; 
            break;

         case 4:  // Left command answer timeout
         case 5:  // Right command answer timeout
            if (timeOutCounter == 0) { // time is outed, next question
               timeOutCounter = timeLimit; 
               totalMode = 1;
            }
            break;

         case 6:  // Left command answer after right
            totalMode = 0;
            bingo();
            leftScore++;    
            break;

         case 7:  // Right command answer after left
            totalMode = 0;
            bingo();
            rightScore++; 
            break;
      }
      setmode(totalMode);  
   }

   if (timeDivCounter == 0) {
      if (timeOutCounter == 0) {
         tone(pinSound, 2000, 500);
         delay(510);
         noTone(pinSound);
      }
      if (timeOutCounter > -1) {
         tone(pinSound, 2000, 70); 
         timeOutCounter--;
      }
      timeDivCounter = timeDivider; 
   }

   if (timeDivCounter > -1) {  
      timeDivCounter--;
   }
}
